@@ -3,7 +3,7 @@ from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 import sys
 import logging
-from ..vos import Client, is_remote_file
+from ..vos import Client
 from ..commonparser import CommonParser, set_logging_level_from_args, \
     exit_on_exception, URI_DESCRIPTION
 
@@ -19,9 +19,9 @@ def _cat(uri, cert_filename=None, head=None):
 
     fh = None
     try:
-        if is_remote_file(uri):
-            view = head and 'header' or 'data'
-            fh = Client(vospace_certfile=cert_filename).open(uri, view=view)
+        view = head and 'header' or 'data'
+        fh = Client(vospace_certfile=cert_filename).open(uri, view=view)
+        if fh.is_remote_file(uri):
             sys.stdout.write(fh.read(return_response=True).text)
             sys.stdout.write('\n\n')
         else:
